SUMATERA
<!DOCTYPE html>
<html lang="id">

<head>
    <!-- Meta tags -->
    <meta charset="utf-8">
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    <meta name="keywords" content="Kelas karyawan, pendaftaran online, biaya kuliah, kelas hybrid, Kuliah karyawan, politeknik piksi kebumen, kampus kelas karyawan kebumen, kelas karyawan kebumen, kelas fleksibel piksi ganesha, kampus murah di kebumen, D3 Akuntansi Keuangan, D3 Akuntansi Perkantoran, D3 Teknik Otomotif, kelas karyawan fleksibel" />
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <title>@yield('title') &mdash; Politeknik Piksi Ganesha Kebumen (Kelas Karyawan)</title>
    <meta name="description" content="Politeknik Piksi Ganesha Indonesia atau dikenal PPGI salah satu Perguruan Tinggi Swasta dan kampus politeknik Terbaik dan unggul di Kota Kebumen jawa tengah, tersedia kelas sabtu, kelas hybrid dan ekstensi dengan biaya murah dan terjangkau cukup Rp 500.000/Bulan dengan jurusan Akuntansi Keuangan, Akuntansi Perkantoran, Teknik Otomotif, Teknik Elektro Dan Rekam Medis, Teknik Elektronika Dan Informatika Komputer." />
    <meta property="og:title" content="Politeknik Piksi Ganesha (Kelas Karyawan)">
    <meta property="og:type" content="website">
    <meta property="og:url" content="https://piksiganesha-kebumen.info">
    <meta property="og:image" content="https://piksiganesha-kebumen.info/images/fb-ogimage.png" />
    <meta property="og:image:width" content="1200" />
    <meta property="og:image:height" content="630" />
    <meta property="og:description" content="Politeknik Piksi Ganesha Indonesia atau dikenal PPGI salah satu Perguruan Tinggi Swasta Terbaik di Kota Kebumen, tersedia kelas sabtu dan ekstensi dengan biaya murah dan terjangkau cukup Rp 500.000/Bulan dengan jurusan Akuntansi Keuangan, Akuntansi Perkantoran, Teknik Otomotif, Teknik Elektro Dan Rekam Medis, Teknik Elektronika Dan Informatika Komputer.">
    <meta name="twitter:card" content="summary_large_image">
    <meta name="twitter:creator" content="@_kuliahkaryawan">
    <meta name="twitter:site" content="@_kuliahkaryawan">
    <meta name="twitter:title" content="Politeknik Piksi Ganesha (Kelas Karyawan)">
    <meta name="twitter:description" content="Politeknik Piksi Ganesha Indonesia atau dikenal PPGI salah satu Perguruan Tinggi Swasta Terbaik di Kota Kebumen, tersedia kelas sabtu dan ekstensi dengan biaya murah dan terjangkau cukup Rp 500.000/Bulan dengan jurusan Akuntansi Keuangan, Akuntansi Perkantoran, Teknik Otomotif, Teknik Elektro Dan Rekam Medis, Teknik Elektronika Dan Informatika Komputer.">
    <meta name="twitter:domain" content="https://piksiganesha-kebumen.info">
    <meta name="twitter:image:src" content="https://piksiganesha-kebumen.info/images/twitter-og.png">
    <meta name="author" content="Kuliah Karyawan Team" />
    <meta http-equiv="cache-control" content="public" />
    <meta name="application-name" content="Politeknik Piksi Ganesha Kebumen | Kuliah Karyawan K2" />
    <meta name="msapplication-TileColor" content="#9A03CC" />
    <meta name="msapplication-TileImage" content="https://piksiganesha-kebumen.info/assets/favicons/mstile-144x144.png" />
    <meta name="msapplication-square70x70logo" content="https://piksiganesha-kebumen.info/assets/favicons/mstile-70x70.png" />
    <meta name="msapplication-square150x150logo" content="https://piksiganesha-kebumen.info/assets/favicons/mstile-150x150.png" />
    <meta name="msapplication-wide310x150logo" content="https://piksiganesha-kebumen.info/assets/favicons/mstile-310x150.png" />
    <meta name="msapplication-square310x310logo" content="https://piksiganesha-kebumen.info/assets/favicons/mstile-310x310.png" />
    <meta name="theme-color" content="#9A03CC" />

    <link rel="apple-touch-icon" sizes="57x57" href="/images/favicons/apple-icon-57x57.png">
    <link rel="apple-touch-icon" sizes="60x60" href="/images/favicons/apple-icon-60x60.png">
    <link rel="apple-touch-icon" sizes="72x72" href="/images/favicons/apple-icon-72x72.png">
    <link rel="apple-touch-icon" sizes="76x76" href="/images/favicons/apple-icon-76x76.png">
    <link rel="apple-touch-icon" sizes="114x114" href="/images/favicons/apple-icon-114x114.png">
    <link rel="apple-touch-icon" sizes="120x120" href="/images/favicons/apple-icon-120x120.png">
    <link rel="apple-touch-icon" sizes="144x144" href="/images/favicons/apple-icon-144x144.png">
    <link rel="apple-touch-icon" sizes="152x152" href="/images/favicons/apple-icon-152x152.png">
    <link rel="apple-touch-icon" sizes="180x180" href="/images/favicons/apple-icon-180x180.png">
    <link rel="icon" type="image/png" sizes="192x192" href="/images/favicons/android-icon-192x192.png">
    <link rel="icon" type="image/png" sizes="32x32" href="/images/favicons/favicon-32x32.png">
    <link rel="icon" type="image/png" sizes="96x96" href="/images/favicons/favicon-96x96.png">
    <link rel="icon" type="image/png" sizes="16x16" href="/images/favicons/favicon-16x16.png">
    <link rel="manifest" href="/images/favicons/manifest.json">
    <meta name="msapplication-TileColor" content="#ffffff">
    <meta name="msapplication-TileImage" content="/images/favicons/ms-icon-144x144.png">
    <meta name="theme-color" content="#ffffff">

    <script>
        var url = '{{ url('Frontend/js/widgetWhatsApp.js') }}';
        var s = document.createElement('script');
        s.type = 'text/javascript';
        s.async = true;
        s.src = url;
        var options = {
            "enabled": true,
            "chatButtonSetting": {
                "backgroundColor": "#4dc247",
                "ctaText": "Kontak Kami",
                "borderRadius": "25",
                "marginLeft": "0",
                "marginBottom": "30",
                "marginRight": "50",
                "position": "right"
            },
            "brandSetting": {
                "brandName": "Insan Tera Semenjana",
                "brandSubTitle": "Yayasan Insan Tera Semenjana",
                "brandImg": "assets/apple-touch-icon.png",
                "welcomeText": "Halo ! Ada yang bisa admin bantu ?",
                "messageText": "Halo Kak, Saya Mau Bertanya, Sumber : Website Insan Tera Semenjana",
                "backgroundColor": "#166f63",
                "ctaText": "Start Chat",
                "borderRadius": "25",
                "autoShow": false,
                "phoneNumber": "6287717173410"
            }
        };
        s.onload = function() {
            CreateWhatsappChatWidget(options);
        };
        var x = document.getElementsByTagName('script')[0];
        x.parentNode.insertBefore(s, x);
    </script>

    {{-- Style --}}
    @stack('prpend-style')
    @stack('addon-style')

</head>

<body>

    {{-- Navbar --}}
    @include('Frontend.Template.navbar')

    <x-topBar title="Pendaftaran Online" />
    {{-- Page Content --}}
    @yield('content')

    {{-- Footer --}}
    @include('Frontend.Template.footer')

    {{-- Script --}}
    @stack('prpend-script')
    @stack('addon-script')
    <!-- disabled -->
    <script>
        document.addEventListener('contextmenu', function(event) {
            event.preventDefault();
            alert('Right Click Disabled.');
        });
    </script>
</body>

</html>
