@section('title', 'Sejarah')

@extends('Frontend.Layouts.app2')
@section('content')
    <br><br>
    <x-header-section-page title="Sejarah  {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }}"
        breadcrumb-home="Home" breadcrumb-current="Sejarah Singkat" />

    <div data-aos="fade-up" class=" flex flex-col my-6 md:my-10 px-4 md:px-20 lg:px-32 xl:px-60">
        <!-- Gambar -->
        {{-- <img src="{{ asset('./images/sambutan/petinggi.png') }}" data-aos="fade-up" class=" mb-5 w-full" alt=""> --}}

        <!-- Konten Teks -->
        <div data-aos="fade-up" class="flex flex-col space-y-4 text-justify font-dmsans text-[14px] md:text-[16px]">
            <p>
                Keberadaan Politeknik Piksi Ganesha Indonesia berawal dari obsesi para tokoh yayasan Bhineka Karya yang
                berdiri tanggal 17 Mei 2002 di Karanganyar dengan SK MENDIKNAS NO. 99/D/O/2002. Saat itu didirikan perguruan
                tinggi bernama Politeknik Dharma Patria Kebumen dengan menggunakan gedung SMK Bhina Karya 2 Karanganyar,
                yang masih satu yayasan dengan Bhineka Karya. Politeknik Dharma Patria Kebumen sendiri mempunyai 4 (empat)
                jurusan, yaitu Akuntansi, Teknik Elektronika, Teknik Mesin dan Teknik Otomotif. Peningkatan mahasiswa
                Politeknik Dharma Patria Kebumen dari tahun ke tahun cenderung meningkat, namun pada tahun 2011 terjadi
                konflik antar pengurus yayasan dan sampai akhirnya pada tahun 2011 Politeknik Dharma Patria Kebumen
                diakuisisi Politeknik Piksi Ganesha Bandung yang terletak di pusat kota kebumen yaitu di jalan Jendral Ahmad
                Yani No. 1 Kebumen.
                <br><br>
                Pada bulan April 2011, mulailah pembukaan penerimaan mahasiswa baru. Dengan manajemen yang baru dan tidak
                kurang juga dari promosi, maka peminat calon mahasiswa baru sangat banyak dan ini peningkatan yang sangat
                signifikan di banding manajemen lama. Masyarakat, khususnya yang baru lulus SLTA sangat antusias sekali
                untuk mendaftar di kampus Politeknik Dharma Patria Kebumen. Bahkan bukan dari yang baru lulus SLTA saja,
                melainkan dari para pejabat desa seperti Lurah, Sekretaris Lurah, Kepala Desa serta Guru-Guru yang masih
                berpendidikan SMA, tertarik untuk mendaftar di Politeknik Dharma Patria Kebumen.

                <br><br>
                Untuk menunjukan komitmennya, pada tanggal 14 November 2012 lembaga telah meresmikan Gedung Rektorat
                Politeknik Dharma Patria Kebumen yang terletak di jalan Letjend Suprapto No. 73 Kebumen (samping Koramil
                Kebumen). Setelah peresmian kampus Politeknik Dharma Patria Kebumen, langsung kedatangan Asesor dari BAN-PT
                untuk visitasi akreditasi yang berlangsung selama 10 hari. Politeknik Dharma Patria pada tanggal 16 Oktober
                2021 resmi berganti nama menjadi Politeknik Piksi Ganesha Indonesia. Proses penyerahan surat keterangan
                perubahan nama dilakukan oleh Ketua Yayasan Piksi Ganesha Indonesia, Dr. K.H. Prihartono, A.H., Drs.,
                S.Sos., M.Kom., M.M kepada Direktur Politeknik Piksi Ganesha.
            </p>


        </div>

        <!-- Bagian Ajakan -->
        <div data-aos="fade-up" class="flex items-center flex-col pt-10">
            <div data-aos="fade-up" class="w-full h-[1px] bg-blue-900 my-4"></div>
            <h1 data-aos="fade-up" class="text-center font-poppins text-[20px] md:text-[30px] font-bold text-primary">
                SEGERA DAFTAR
            </h1>
            <p data-aos="fade-up" class="text-center mb-5 text-[12px] md:text-[14px] lg:text-[16px]">
                Bergabunglah bersama {{ $settings['nama kampus'] ?? 'Nama kampus tidak tersedia' }} dan Bangun Wawasan,
                Bentuk Karakter, Jadilah Pembawa Perubahan!
            </p>
            <x-button url="/pendaftaran">DAFTAR SEKARANG</x-button>
        </div>
    </div>
@endsection
